.. image:: https://github.com/luttik/repr_utils/workflows/CI/badge.svg
    :alt: actions batch
    :target: https://github.com/Luttik/repr_utils/actions?query=workflow%3ACI+branch%3Amaster
.. image:: https://badge.fury.io/py/repr-utils.svg
    :alt: pypi
    :target: https://pypi.org/project/repr-utils/

.. image:: https://codecov.io/gh/luttik/repr_utils/branch/master/graph/badge.svg
    :alt: codecov
    :target: https://codecov.io/gh/luttik/repr_utils

REPR-UTIL
---------
A toolkit to quickly display elements in tools like `jupyter`_ by building upon `ipython rich display`_.

Contains simple objects that will automatically be converted to the right format based on the context.

Installation
============
Run :code:`pip install repr-utils`

Examples
========
Look at `the examples notebook`_

Supports:
=========
- Raw Text
- HTML
- Markdown
- Latex

Current objects:
================
- Header
- Table

Relevant links:
===============
- `pypi`_
- `github`_

Contributions are appreciated.

.. _`the examples notebook`: examples.ipynb
.. _`pypi`: https://pypi.org/project/repr-utils/
.. _`github`: https://github.com/Luttik/repr_utils/
.. _`ipython rich display`: https://ipython.readthedocs.io/
.. _`jupyter`: https://jupyter.org/
